==> mozilla-source-0.9.9.tar.bz2: mozilla/extensions/transformiix/source/xslt/txTextOutput.cpp <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the TransforMiiX XSLT processor.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2001
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Peter Van der Beken <peterv@netscape.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "txTextOutput.h"
#include "TxString.h"

txTextOutput::txTextOutput()
{
}

txTextOutput::~txTextOutput()
{
}

void txTextOutput::attribute(const String& aName,
                             const PRInt32 aNsID,
                             const String& aValue)
{
}

void txTextOutput::characters(const String& aData)
{
    *mOut << aData;
}

void txTextOutput::charactersNoOutputEscaping(const String& aData)
{
    characters(aData);
}

void txTextOutput::comment(const String& aData)
{
}

void txTextOutput::endDocument()
{
}

void txTextOutput::endElement(const String& aName,
                              const PRInt32 aNsID)
{
}

void txTextOutput::processingInstruction(const String& aTarget,
                                         const String& aData)
{
}

void txTextOutput::startDocument()
{
}

void txTextOutput::startElement(const String& aName,
                                const PRInt32 aNsID)
{
}

void txTextOutput::getOutputStream(ostream** aOutputStream)
{
    if (aOutputStream)
        *aOutputStream = mOut;
}

void txTextOutput::setOutputStream(ostream* aOutputStream)
{
    mOut = aOutputStream;
}

void txTextOutput::setOutputFormat(txOutputFormat* aOutputFormat)
{
    mOutputFormat.reset();
    mOutputFormat.merge(*aOutputFormat);
    mOutputFormat.setFromDefaults();
}

==> mozilla-source-1.3.tar.bz2: mozilla/extensions/transformiix/source/xslt/txTextOutput.cpp <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the TransforMiiX XSLT processor.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2001
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Peter Van der Beken <peterv@netscape.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "txTextOutput.h"

txTextOutput::txTextOutput(ostream* aOut)
    : mOut(aOut)
{
}

txTextOutput::~txTextOutput()
{
}

void txTextOutput::attribute(const nsAString& aName,
                             const PRInt32 aNsID,
                             const nsAString& aValue)
{
}

void txTextOutput::characters(const nsAString& aData)
{
    *mOut << NS_ConvertUCS2toUTF8(aData).get();
}

void txTextOutput::charactersNoOutputEscaping(const nsAString& aData)
{
    characters(aData);
}

void txTextOutput::comment(const nsAString& aData)
{
}

void txTextOutput::endDocument()
{
}

void txTextOutput::endElement(const nsAString& aName,
                              const PRInt32 aNsID)
{
}

void txTextOutput::processingInstruction(const nsAString& aTarget,
                                         const nsAString& aData)
{
}

void txTextOutput::startDocument()
{
}

void txTextOutput::startElement(const nsAString& aName,
                                const PRInt32 aNsID)
{
}
